@@ -21,9 +21,10 @@ use Data::FormValidator::Filters qw/:filters/;
 use Data::FormValidator::Constraints (qw/:validators :matchers/);
 use vars qw/$AUTOLOAD $VERSION/;
 use overload
-  'bool' => \&_bool_overload_based_on_success;
+  'bool' => \&_bool_overload_based_on_success,
+  fallback => 1;
 
-$VERSION = 4.10;
+$VERSION = 4.13;
 
 =pod
 
